@@ -120,15 +120,16 @@ sub help {
     print <<_;
 
 Usage: p6doc [options] [document-id]
-View the Perl 6 Canon.
 
 Possible values for document-id are:
   A01 - A33  (Perl 6 Apocalypses)
   E01 - E33  (Perl 6 Exegeses)
   S01 - S33  (Perl 6 Synopses)
-  F01 - F33  (Perl 6 FAQ)
   O01 - O33  (Perl 6 Overview)
+  F01 - F33  (Perl 6 FAQ)
   T01        (Perl 6 Tutorial)
+  P00 - P09  (Perl 6 Tables)
+  M01 - M09  (Mazine Articles)
 
 Valid options:
   -h,  --help       Print this help screen
@@ -216,7 +217,7 @@ the Perl 6 Design Team.
          Debugging                         (A20*)
     S22* CPAN
          Portable Perl
-    S26* Perl Documentation
+    S26  Perl Documentation
     S27* Perl Culture
     S28* Special Names
     S29* Functions
@@ -282,7 +283,7 @@ Damian Conway's Exegeses are extensions of each Apocalypse.  Each
 Exegesis is built around a practical code example that applies and
 explains the new ideas.
 
-=head2 Overview and FAQ
+=head2 Docs: Overview and FAQ
 
 These are shorter summaries about a smaller specific topic. They are
 written mostly by the crazy Pugs people and replacing some of the
@@ -318,11 +319,15 @@ Perl6::Doc provides a class method to get the raw text of a document:
 =head1 SOURCES
 
 A couple of paragraphs from _Perl 6 Essentials_ were used for the
-overview. Most docs are from the official Perl development site. 
+overview. Most of the Bible docs (Apocalypses, Exegeses, Synopses)
+are from the official Perl development site. 
 
 http://dev.perl.org/perl6/
 
-All draft Synopses were taken out of the Pugs SVN repository.
+All draft Synopses, Overview, FAQ and Tutorial pages were taken out 
+of the Pugs SVN repository.
+
+http://svn.pugscode.org/pugs/docs/Perl6/
 
 =head1 PACKAGING
 
